IPv6 Server extension configuration
===================================

These are the server extensions for Technicolor CPEs. Currently the only option is the SOL_MAX_RT variant that
Technicolor implements, which is the same option as the standard SOL_MAX_RT but with a different type number.


Overview of section types
-------------------------

.. toctree::
    :maxdepth: 2

    handler_factory
